@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoice_pdf.php,v 1.7 2005/08/04 19:05:30 alec Exp $
+ *  $Id: invoice_pdf.php,v 1.7.2.3 2007/06/21 12:31:00 alec Exp $
  */
 // Faktury w PDF, do uycia z formularzami FT-0100 (c) Polarnet
 // w razie pyta mailto:lexx@polarnet.org
@@ -380,7 +380,8 @@ function invoice_body()
 	    invoice_simple_form_fill(14,3,0.4);
 	    break;
 	default:
-	    require($_MODULES_DIR.'/'.$CONFIG['invoices']['template_file']);
+	    if(file_exists($_MODULES_DIR.'/'.$CONFIG['invoices']['template_file']))
+		    require($_MODULES_DIR.'/'.$CONFIG['invoices']['template_file']);
     }
     if (!($invoice['last'])) $id=$pdf->newPage(1,$id,'after');
 }
