@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
  *  USA.
  *
- *  $Id: initLMS.php,v 1.13 2005/08/04 19:05:30 alec Exp $
+ *  $Id: initLMS.php,v 1.13.2.3 2007/06/21 12:30:59 alec Exp $
  */
 
 // REPLACE THIS WITH PATH TO YOU CONFIG FILE
@@ -75,6 +75,8 @@ function lms_parse_ini_file($filename, $process_sections = false)
 	return $ini_array;
 }
 
+$CONFIG = array();
+
 foreach(lms_parse_ini_file($CONFIG_FILE, true) as $key => $val)
 	$CONFIG[$key] = $val;
 
