@@ -1,7 +1,7 @@
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: config.c,v 1.8 2005/10/26 14:55:19 alec Exp $
+ *  $Id: config.c,v 1.8.2.3 2006/05/15 11:17:25 alec Exp $
  */
 
 #include <stdio.h>
@@ -75,7 +75,7 @@ unsigned char * parse(unsigned char *string)
 		continue; 
 	    } 
 
-	    out[k++] = c; i++; // just an escaped character
+	    out[k++] = '\\'; // just rewrite that backslash
 	}
 	else
 	{
