@@ -1,4 +1,4 @@
-/* $Id: config.h,v 1.2 2005/04/25 12:03:24 alec Exp $ */
+/* $Id: config.h,v 1.3 2005/09/22 06:32:58 alec Exp $ */
 
 #ifndef _CONFIG_H_
 #define _CONFIG_H_
@@ -11,9 +11,6 @@
 #ifdef USE_PGSQL
 #include "../dbdrivers/pgsql/db.h"
 #endif
-#ifdef USE_SQLITE
-#include "../dbdrivers/sqlite/db.h"
-#endif
 
 /* Maximum size of variable name or section name*/
 #define NAMESZ		100
