@@ -16,7 +16,7 @@ struct dhcp_module
 	unsigned char *file;
 	unsigned char *command;
 	unsigned char *networks;
-	unsigned char *usergroups;
+	unsigned char *customergroups;
 };
 
 struct net
