@@ -18,9 +18,11 @@ struct payments_module
 #define MONTHLY 3
 #define WEEKLY 2
 #define DAILY 1
+#define DISPOSABLE 0
 
 #define _YEARLY_ "5"
 #define _QUARTERLY_ "4"
 #define _MONTHLY_ "3"
 #define _WEEKLY_ "2"
 #define _DAILY_ "1"
+#define _DISPOSABLE_ "0"
