@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: Auth.class.php,v 1.11 2005/08/17 16:38:36 alec Exp $
+ *  $Id: Auth.class.php,v 1.13.2.5 2007/06/18 13:27:17 alec Exp $
  */
 
 class Auth {
@@ -37,8 +37,8 @@ class Auth {
 	var $ip;
 	var $lastip;
 	var $error;
-	var $_version = '1.7.4 Wraith';
-	var $_revision = '$Revision: 1.11 $';
+	var $_version = '1.8.12 Tagan';
+	var $_revision = '$Revision: 1.13.2.5 $';
 	var $DB = NULL;
 	var $SESSION = NULL;
 
@@ -46,7 +46,16 @@ class Auth {
 	{
 		$this->DB = &$DB;
 		$this->SESSION = &$SESSION;
-		$this->ip = str_replace('::ffff:', '', $_SERVER['REMOTE_ADDR']);
+                $this->_revision = eregi_replace('^.Revision: ([0-9.]+).*','\1', $this->_revision);
+	       		
+		if(isset($_SERVER['HTTP_X_FORWARDED_FOR']) && $_SERVER['HTTP_X_FORWARDED_FOR'])
+			$ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
+		elseif(isset($_SERVER['HTTP_CLIENT_IP']) && $_SERVER['HTTP_CLIENT_IP'])
+			$ip = $_SERVER['HTTP_CLIENT_IP'];
+		else
+			$ip = $_SERVER['REMOTE_ADDR'];
+		  
+		$this->ip = str_replace('::ffff:', '', $ip);
 		
 		if(isset($_GET['override']))
 			$loginform = $_GET['loginform'];
@@ -107,7 +116,7 @@ class Auth {
 				if(!$this->passverified)
 					writesyslog('Bad password for '.$this->login, LOG_WARNING);
 				
-				$this->DB->Execute('UPDATE users SET failedlogindate=?, failedloginip=? WHERE login=?',array(time(),$_SERVER['REMOTE_ADDR'],$this->login));
+				$this->DB->Execute('UPDATE users SET failedlogindate=?, failedloginip=? WHERE login=?',array(time(), $this->ip, $this->login));
 			}
 			$this->LogOut();
 		}
@@ -145,31 +154,33 @@ class Auth {
 			return TRUE;
 		
 		$allowedlist = explode(',', $hosts);
-		$isin = FALSE;
 		
 		foreach($allowedlist as $value)
 		{
-			list($net,$mask) = sscanf($value, '%[0-9.]/%[0-9]');
+            		$net = '';
+		        $mask = '';
+
+	                if(strpos($value, '/')===FALSE)
+				$net = $value;
+			else
+			        list($net, $mask) = explode('/', $value);
+			
 			$net = trim($net);
 			$mask = trim($mask);
+			
 			if($mask == '')
-				$mask = '32';
-			if($mask >= 0 || $mask <= 32)
-				$mask = prefix2mask($mask);
+			        $mask = '255.255.255.255';
+			elseif(is_numeric($mask))
+			        $mask = prefix2mask($mask);
+			
 			if(isipinstrict($this->ip, $net, $mask))
 			{
-				$isin = TRUE;
-				break;
+			        return TRUE;
 			}
 		}
 
-		if($isin)
-			return TRUE;
-		else 
-		{
-			$this->error = trans('Access denied!');
-			return FALSE;
-		}
+		$this->error = trans('Access denied!');
+		return FALSE;
 	}
 	
 	function VerifyUser()
