@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,17 +21,17 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: checkconfig.php,v 1.2 2005/05/13 20:23:58 alec Exp $
+ *  $Id: checkconfig.php,v 1.2.2.3 2006/06/11 09:37:43 alec Exp $
  */
 
 function chkconfig($value, $default = FALSE)
 {
-	if(eregi('^(1|y|on|yes|true|tak|t)$', $value))
+	if(!isset($value) || $value == '')
+		return $default;
+	elseif(eregi('^(1|y|on|yes|true|tak|t)$', $value))
 		return TRUE;
 	elseif(eregi('^(0|n|no|off|false|nie)$', $value))
 		return FALSE;
-	elseif(!isset($value) || $value == '')
-		return $default;
 	else
 		trigger_error('Incorrect option value: '.$value);
 }
