@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,25 +21,25 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: checkdirs.php,v 1.29 2005/10/28 17:19:12 alec Exp $
+ *  $Id: checkdirs.php,v 1.29.2.3 2006/01/16 09:35:23 alec Exp $
  */
 
 if(!is_dir($_SMARTY_COMPILE_DIR))
 	die('Missing directory <B>'.$_SMARTY_COMPILE_DIR.'</B>. Can anybody make them?');
 
 if(!is_writable($_SMARTY_COMPILE_DIR))
-	die('Can\'t write to directory <B>'.$_SMARTY_COMPILE_DIR.'</B>. Run: <BR><PRE>chown '.posix_geteuid().'.'.posix_getegid().' '.$_SMARTY_COMPILE_DIR."\nchmod 755 ".$_SMARTY_COMPILE_DIR.'</PRE>This helps me to work. Thanks.');
+	die('Can\'t write to directory <B>'.$_SMARTY_COMPILE_DIR.'</B>. Run: <BR><PRE>chown '.posix_geteuid().':'.posix_getegid().' '.$_SMARTY_COMPILE_DIR."\nchmod 755 ".$_SMARTY_COMPILE_DIR.'</PRE>This helps me to work. Thanks.');
 
 if(!is_dir($_BACKUP_DIR))
 	die('Missing directory <B>'.$_BACKUP_DIR.'</B>. Can anybody make them?');
 	
 if(!is_writable($_BACKUP_DIR))
-	die('Can\'t write to directory <B>'.$_BACKUP_DIR.'</B>. Run: <BR><PRE>chown '.posix_geteuid().'.'.posix_getegid().' '.$_BACKUP_DIR."\nchmod 755 ".$_BACKUP_DIR.'</PRE>This helps me to work. Thanks.');
+	die('Can\'t write to directory <B>'.$_BACKUP_DIR.'</B>. Run: <BR><PRE>chown '.posix_geteuid().':'.posix_getegid().' '.$_BACKUP_DIR."\nchmod 755 ".$_BACKUP_DIR.'</PRE>This helps me to work. Thanks.');
 
 if(!is_dir($_DOC_DIR))
 	die('Missing directory <B>'.$_DOC_DIR.'</B>. Can anybody make them?');
 	
 if(!is_writable($_DOC_DIR))
-	die('Can\'t write to directory <B>'.$_DOC_DIR.'</B>. Run: <BR><PRE>chown '.posix_geteuid().'.'.posix_getegid().' '.$_DOC_DIR."\nchmod 755 ".$_DOC_DIR.'</PRE>This helps me to work. Thanks.');
+	die('Can\'t write to directory <B>'.$_DOC_DIR.'</B>. Run: <BR><PRE>chown '.posix_geteuid().':'.posix_getegid().' '.$_DOC_DIR."\nchmod 755 ".$_DOC_DIR.'</PRE>This helps me to work. Thanks.');
 
 ?>
