@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: common.php,v 1.88 2005/09/11 13:49:22 hunter Exp $
+ *  $Id: common.php,v 1.89.2.3 2006/07/22 19:25:52 alec Exp $
  */
 
 // Common functions, that making it in class would be nonsense :)
@@ -93,6 +93,7 @@ function hostname()
 			exec('hostname -f',$return);
 			$hostname=$return[0];
 			break;
+		case 'Darwin':
 		case 'FreeBSD':
 		case 'OpenBSD':
 		case 'NetBSD':
@@ -512,12 +513,11 @@ function docnumber($number=NULL, $template=NULL, $time=NULL)
 }
 
 // our finance round:
-
-function f_round ($value)
+function f_round($value)
 {
 	$value = str_replace(',','.', $value);
-	$value = round ( (float) $value,2);
-
+	$value = round ( (float) $value, 2);
 	return $value;
-}	
+}
+
 ?>
