@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: functions.php,v 1.11 2005/06/26 07:41:14 alec Exp $
+ *  $Id: functions.php,v 1.11.2.3 2007/06/22 15:18:23 alec Exp $
  */
 
 function bankaccount($id)
@@ -47,6 +47,8 @@ function uptimef($ts)
 	$days  = floor($hours / 24);
 	$hours = floor($hours - ($days * 24));
 	$min= floor($min - ($days * 60 * 24) - ($hours * 60));
+	$result = '';
+
 	if ($days != 0)
 	{
 		$result = $days;
