@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- * (C) Copyright 2001-2005 LMS Developers
+ * (C) Copyright 2001-2006 LMS Developers
  *
  * Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  * USA.
  *
- * $Id: menu.php,v 1.21 2005/10/03 20:23:25 alec Exp $
+ * $Id: menu.php,v 1.23.2.2 2006/01/16 09:35:23 alec Exp $
  */
 
 $menu = array(
@@ -102,7 +102,7 @@ $menu = array(
 				),
 				array(
 					'name' => trans('Printing'),
-					'link' =>'?m=print&menu=customers',
+					'link' =>'?m=customerprint',
 					'tip' => trans('Printing'),
 				),
 			),		 
@@ -116,34 +116,29 @@ $menu = array(
 			'accesskey' =>'k',
 			'prio' =>'10',
 			'submenu' => array(
-				// node
 				array(
 					'name' => trans('List'),
 					'link' => '?m=nodelist',
 					'tip' => trans('List of nodes'),
 				),
-				// node
 				array(
 					'name' => trans('New Node'),
 					'link' => '?m=nodeadd',
 					'tip' => trans('Allows you to add new node'),
 				),
-				// node
 				array(
 					'name' => trans('Search'),
 					'link' => '?m=nodesearch',
 					'tip' => trans('Allows you to search node'),
 				),
-				// node
 				array(
 					'name' => trans('Messages'),
 					'link' => '?m=nodewarn',
 					'tip' => trans('Allows you to send message to nodes'),
 				),
-				// node
 				array(
 					'name' => trans('Printing'),
-					'link' => '?m=print&menu=nodes',
+					'link' => '?m=nodeprint',
 					'tip' => trans('Allows you to print node list'),
 				),
 			),
@@ -261,7 +256,7 @@ $menu = array(
 				),
 				array(
 					'name' => trans('Printing'),
-					'link' => '?m=print&menu=finances',
+					'link' => '?m=print',
 					'tip' => trans('Printing of financial statements'),
 				),
 			),
@@ -337,7 +332,7 @@ $menu = array(
 			'name' => trans('Stats'),
 			'img' =>'traffic.gif',
 			'link' =>'?m=traffic',
-			'tip' => trans('Statistics on Internet Link Usage'),
+			'tip' => trans('Statistics of Internet Link Usage'),
 			'accesskey' =>'x',
 			'prio' =>'45',
 			'submenu' => array(
@@ -373,7 +368,7 @@ $menu = array(
 				),
 				array(
 					'name' => trans('Printing'),
-					'link' => '?m=print&menu=traffic',
+					'link' => '?m=trafficprint',
 					'tip' => trans('Printing of customer stats'),
 				),
 			),
