@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: configlist.php,v 1.24 2005/10/01 17:42:56 alec Exp $
+ *  $Id: configlist.php,v 1.24.2.3 2006/01/16 09:35:26 alec Exp $
  */
 
 function GetConfigList($order='var,asc')
@@ -319,6 +319,14 @@ function GetConfigList($order='var,asc')
 					case 'type':
 						$config[$idx]['description'] = trans('Documents type. You can use "html" or "pdf". Default: html.');
 					break;
+
+					case 'print_balance_history':
+						$config[$idx]['description'] = trans('If true on invoice (html) will be printed history of financial operations on customer account. Default: not set.');
+					break;
+					
+					case 'print_balance_history_limit':
+						$config[$idx]['description'] = trans('Number of Records on customer balance list on invoice. Specify last x records. Default: 10.');
+					break;
 					
 					default:
 						$config[$idx]['description'] = trans('Unknown option. No description.');
