@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: customerbalanceok.php,v 1.7 2005/09/29 07:35:51 alec Exp $
+ *  $Id: customerbalanceok.php,v 1.8.2.2 2006/01/16 09:35:27 alec Exp $
  */
 
 $customerid = $_GET['id'];
@@ -32,8 +32,8 @@ if($LMS->CustomerExists($customerid))
 
 	if($balance<0)
 	{
-		$DB->Execute('INSERT INTO cash (time, userid, value, customerid, comment)
-			VALUES (?NOW?, ?, ?, ?, ?)', 
+		$DB->Execute('INSERT INTO cash (time, type, userid, value, customerid, comment)
+			VALUES (?NOW?, 1, ?, ?, ?, ?)', 
 			array($AUTH->id, 
 				str_replace(',','.', $balance*-1),
 				$customerid,
