@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbrecover.php,v 1.43 2005/07/20 14:03:17 alec Exp $
+ *  $Id: dbrecover.php,v 1.43.2.3 2006/04/05 11:36:30 alec Exp $
  */
 
 function DBLoad($filename=NULL)
@@ -41,10 +41,10 @@ function DBLoad($filename=NULL)
 	$DB->BeginTrans(); // przyspieszmy dziaanie jeeli baza danych obsuguje transakcje
 	while(!feof($file))
 	{
-		$line = fgets($file,4096);
+		$line = fgets($file,8192);
 		if($line!='')
 		{
-			$line=str_replace(';\n','',$line);
+			$line=str_replace(";\n", '', $line);
 			$DB->Execute($line);
 		}
 	}
