@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: eventsearch.php,v 1.11 2005/08/05 09:06:34 alec Exp $
+ *  $Id: eventsearch.php,v 1.11.2.3 2006/02/24 07:28:27 alec Exp $
  */
 
 function EventSearch($search)
@@ -58,7 +58,7 @@ function EventSearch($search)
 					}
 		}
 	
-	if($userid)
+	if($search['userid'])
 		return $list2;	
 	else	
 		return $list;
