@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: genfake.php,v 1.48 2005/07/23 17:21:40 alec Exp $
+ *  $Id: genfake.php,v 1.50.2.4 2006/01/16 09:35:27 alec Exp $
  */
 
 // Lastnames
@@ -1835,7 +1835,7 @@ if(isset($_GET['l']) && sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l'])
 	$SMARTY->display('header.html');
 	echo '<BLOCKQUOTE><BR><H1>'.trans('Generating random data').'</H1>';
 
-	echo '<B>'.trans('Clearing database...').'</B><BR>';
+	echo '<B>'.trans('Clearing database...').'</B><BR>'; flush();
 	$DB->Execute('DELETE FROM nodes');
 	$DB->Execute('DELETE FROM customers');
 	$DB->Execute('DELETE FROM cash');
@@ -1877,7 +1877,7 @@ if(isset($_GET['l']) && sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l'])
 	$DB->Execute('INSERT INTO taxes (label, value, taxed) VALUES(?,?,?)',array('7%', 7, 1));
 	$DB->Execute('INSERT INTO taxes (label, value, taxed) VALUES(?,?,?)',array('22%', 22, 1));
 
-	echo '<B>'.trans('Generating subscriptions...').'</B><BR>';
+	echo '<B>'.trans('Generating subscriptions...').'</B><BR>'; flush();
 	$tariffdata = array( 'name' => 'Lite', 'description' => 'Lite Tariff', 'value' => '30', 'taxid' => '1', 'prodid' => '', 'uprate' => '64', 'upceil' => '64', 'downrate' => '128', 'downceil' => '128', 'climit' => '0', 'plimit' => '0');
 	$LMS->TariffAdd($tariffdata);
 	$tariffdata = array( 'name' => 'Standart', 'description' => 'Standart Tariff', 'value' => '60', 'taxid' => '2', 'prodid' => '', 'uprate' => '128', 'upceil' => '128', 'downrate' => '256', 'downceil' => '256', 'climit' => '0', 'plimit' => '0');
@@ -1885,7 +1885,7 @@ if(isset($_GET['l']) && sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l'])
 	$tariffdata = array( 'name' => 'Gold', 'description' => 'Gold Tariff', 'value' => '120', 'taxid' => '3', 'prodid' => '', 'uprate' => '256', 'upceil' => '256', 'downrate' => '512', 'downceil' => '512', 'climit' => '0', 'plimit' => '0');
 	$LMS->TariffAdd($tariffdata);
 
-	echo '<B>'.trans('Generating payments...').'</B><BR>';
+	echo '<B>'.trans('Generating payments...').'</B><BR>'; flush();
 	$paymentdata = array( 'name' => 'DSL-2048', 'description' => 'Internet Link subscription', 'value' => '200', 'creditor' => 'Internet Super Provider Ltd.', 'period' => MONTHLY, 'at' => '10');
 	$LMS->PaymentAdd($paymentdata);
 	$paymentdata = array( 'name' => 'Server Room', 'description' => 'Rent', 'value' => '300', 'creditor' => 'Residential Cooperative "VIEW"', 'period' => MONTHLY, 'at' => '20');
@@ -1893,12 +1893,12 @@ if(isset($_GET['l']) && sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l'])
 	$paymentdata = array( 'name' => 'Domain', 'description' => 'Domain "our.net" subscription', 'value' => '150', 'creditor' => 'NASK', 'period' => YEARLY, 'at' => '31');
 	$LMS->PaymentAdd($paymentdata);
 	
-	echo '<B>'.trans('Generating network...').'</B><BR>';
+	echo '<B>'.trans('Generating network...').'</B><BR>'; flush();
 	$prefix = ($_GET['l']*2>1024) ? 16 : 22;
 	$netdata = array( 'name' => 'LAN1', 'address' => '192.168.0.0', 'prefix' => $prefix, 'gateway' => '192.168.0.1', 'dns' => '192.168.0.1', 'dns2' => '192.168.3.254', 'domain' => 'ultralan.net', 'wins' => '192.168.0.2', 'dhcpstart' => '192.168.3.230', 'dhcpend' => '192.168.3.253', 'interface' => 'eth0');
 	$LMS->NetworkAdd($netdata);
 
-	echo '<B>'.trans('Generating customers...').'</B><BR>';	
+	echo '<B>'.trans('Generating customers...').'</B><BR>';	flush();
 	$startip = ip_long('192.168.0.0')+1;
 	$cnt = 0;
 	$lnsize = sizeof($lastnames);
@@ -1953,7 +1953,7 @@ if(isset($_GET['l']) && sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l'])
 		$startip ++;
 	}
 	
-	echo '<B>'.trans('Generating network hardware and connections...').'</B><BR>';
+	echo '<B>'.trans('Generating network hardware and connections...').'</B><BR>'; flush();
 	$nodes = $DB->GetOne('SELECT count(id) FROM nodes');
 	$sprod = sizeof($producer);
 	$i = 0;
@@ -1990,7 +1990,43 @@ if(isset($_GET['l']) && sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l'])
 		$startip++;
 		if($i>1)
 			$LMS->NetDevLink($i,$i-1);
-	}	
+	}
+	
+	if($_GET['i'])
+	{
+		echo '<B>'.trans('Generating invoices...').'</B><BR>'; flush();
+		
+		if($_GET['i'] > 100) $_GET['i'] = 100;
+		
+		$inv['number'] = 0;
+		$inv['paytime'] = 14;
+		$inv['paytype'] = trans('CASH');
+		$inv['numberplanid'] = 0;
+		$inv['type'] = DOC_INVOICE;
+		$inv['cdate'] = time() - ($_GET['i']+1) * 86400;
+		$contents['prodid'] = '';
+		$contents['tariffid'] = 0;
+		$contents['jm'] = trans('item no.');
+		$contents['name'] = trans('Subscription');
+		
+		$customers = $DB->GetAll('SELECT '.$DB->Concat('UPPER(lastname)',"' '",'customers.name').' AS customername, id, ssn, address, zip, city, ten FROM customers');
+					    
+		if($customers)
+			for($n=0; $n<$_GET['i']; $n++)
+			{
+				$contents['taxid'] = mt_rand(1,3);
+				$contents['count'] = mt_rand(1,3);
+				$contents['valuebrutto'] = 100+$n*10+$n*0.1;
+				$inv['cdate'] += 86400;
+				
+				foreach($customers as $c)
+				{
+					$inv['number']++;
+					$cont[0] = $contents;
+					$LMS->AddInvoice(array('customer' => $c, 'contents' => $cont, 'invoice' => $inv));
+				}
+			}
+	}			
 
 	echo '<P><B><A HREF="javascript:window.close();">'.trans('You can close this window now.').'</A></B></BLOCKQUOTE>';
 	$SMARTY->display('footer.html');
@@ -1999,7 +2035,13 @@ else
 {
 	$SMARTY->display('header.html');
 	echo '<H1>'.trans('Generating random data').'</H1>';
-	echo '<FORM METHOD="GET" ACTION="?" TARGET="_BLANK"><INPUT TYPE="HIDDEN" VALUE="genfake" NAME="m">'.trans('How many records? (max: 65000)').' <FONT COLOR="RED">'.trans('WARNING! THIS WILL DELETE ALL DATA FROM DATABASE!!!').'</FONT> <INPUT TYPE="TEXT" NAME="l" SIZE="30"></FORM>';
+	echo '<form method="get" action="?" target="_blank">';
+	echo '<input type="hidden" name="m" value="genfake">';
+	echo '<input type="submit" class="hiddenbtn">';
+	echo '<font class="alert bold">'.trans('WARNING! THIS WILL DELETE ALL DATA FROM DATABASE!!!').'</font><p>';
+	echo trans('How many customers? (max.65000):').' <input type="text" name="l" size="5"><br>';
+	echo trans('How many invoices for each customer? (max.100):').' <input type="text" name="i" size="5">';
+	echo '<br><input type="submit" value="'.trans('Generate').'"></form>';
 	$SMARTY->display('footer.html');
 }
 
