@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoice.php,v 1.52 2005/09/08 12:56:10 alec Exp $
+ *  $Id: invoice.php,v 1.55.2.6 2006/05/03 19:39:01 alec Exp $
  */
 
 if (strtolower($CONFIG['invoices']['type']) == 'pdf')
@@ -54,35 +54,41 @@ if($_GET['print'] == 'cached')
 		$SESSION->close();
 		die;
 	}
+
+	$layout['pagetitle'] = trans('Invoices');
+	$SMARTY->display('invoiceheader.html');
 	
 	if($_GET['cash'])
 	{
 		foreach($ids as $cashid)
 		{
-			// we need to check if that document is an invoice
-			if($invoiceid = $DB->GetOne('SELECT docid FROM cash, documents WHERE docid = documents.id AND documents.type=1 AND cash.id = ?', array($cashid)))
+			// we need to check if that document is an invoice or credit note
+			if($invoiceid = $DB->GetOne('SELECT docid FROM cash, documents WHERE docid = documents.id AND (documents.type=? OR documents.type=?) AND cash.id = ?', array(DOC_INVOICE, DOC_CNOTE, $cashid)))
 				$idsx[] = $invoiceid;
 		}
 		$ids = array_unique((array)$idsx);
 	}
 
-	$layout['pagetitle'] = trans('Invoices');
-	$SMARTY->display('invoiceheader.html');
-	
 	sort($ids);
-	$which = ($_GET['which'] != '' ? $_GET['which'] : trans('ORIGINAL+COPY'));
 	
-	$count = (strstr($which, '+') ? sizeof($ids)*2 : sizeof($ids));
+	if($_GET['original']) $which[] = trans('ORIGINAL');
+	if($_GET['copy']) $which[] = trans('COPY');
+	if($_GET['duplicate']) $which[] = trans('DUPLICATE');
+
+	if(!sizeof($which)) $which[] = trans('ORIGINAL');
+	
+	$count = sizeof($ids) * sizeof($which);
 	$i=0;
 	foreach($ids as $idx => $invoiceid)
 	{
 		$invoice = $LMS->GetInvoiceContent($invoiceid);
 		$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
-		foreach(split('\+', $which) as $type)
+		foreach($which as $type)
 		{
 			$i++;
 			if($i == $count) $invoice['last'] = TRUE;
 			$SMARTY->assign('type',$type);
+			$SMARTY->assign('duplicate',$type==trans('DUPLICATE') ? TRUE : FALSE);
 			$SMARTY->assign('invoice',$invoice);
 			if($invoice['invoice'])
 				$SMARTY->display($CONFIG['invoices']['cnote_template_file']);
@@ -95,32 +101,39 @@ if($_GET['print'] == 'cached')
 elseif($_GET['fetchallinvoices'])
 {
 	$layout['pagetitle'] = trans('Invoices');
-	$SMARTY->display('invoiceheader.html');
-	$which = ($_GET['which'] != '' ? $_GET['which'] : trans('ORIGINAL+COPY'));
-	
+
 	$ids = $DB->GetCol('SELECT id FROM documents 
-				WHERE cdate > ? AND cdate < ? AND type = 1'
+				WHERE cdate >= ? AND cdate <= ? AND (type = ? OR type = ?)'
 				.($_GET['customerid'] ? ' AND customerid = '.$_GET['customerid'] : '')
-				.' ORDER BY cdate',
-				array($_GET['from'], $_GET['to']));
+				.' ORDER BY customerid',
+				array($_GET['from'], $_GET['to'], DOC_INVOICE, DOC_CNOTE));
 	if(!$ids)
 	{
 		$SESSION->close();
 		die;
 	}
 
-	$count = (strstr($which, '+') ? sizeof($ids)*2 : sizeof($ids));
+	if($_GET['original']) $which[] = trans('ORIGINAL');
+	if($_GET['copy']) $which[] = trans('COPY');
+	if($_GET['duplicate']) $which[] = trans('DUPLICATE');
+	
+	if(!sizeof($which)) $which[] = trans('ORIGINAL');
+
+	$count = sizeof($ids) * sizeof($which);
 	$i=0;
 
+	$SMARTY->display('invoiceheader.html');
+
 	foreach($ids as $idx => $invoiceid)
 	{
 		$invoice = $LMS->GetInvoiceContent($invoiceid);
 		$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
-		foreach(split('\+', $which) as $type)
+		foreach($which as $type)
 		{
 			$i++;
 			if($i == $count) $invoice['last'] = TRUE;
 			$SMARTY->assign('type',$type);
+			$SMARTY->assign('duplicate',$type==trans('DUPLICATE') ? TRUE : FALSE);
 			$SMARTY->assign('invoice',$invoice);
 			if($invoice['invoice'])
 				$SMARTY->display($CONFIG['invoices']['cnote_template_file']);
@@ -134,7 +147,7 @@ elseif($_GET['fetchsingle'])
 {
 	$invoice = $LMS->GetInvoiceContent($_GET['id']);
 	$number = docnumber($invoice['number'], $invoice['template'], $invoice['cdate']);
-	if($invoice['doctype']==DOC_INVOICE)
+	if( !$invoice['invoice'])
 		$layout['pagetitle'] = trans('Invoice No. $0', $number);
 	else
 		$layout['pagetitle'] = trans('Credit Note No. $0', $number);
@@ -152,7 +165,7 @@ elseif($_GET['fetchsingle'])
 elseif($invoice = $LMS->GetInvoiceContent($_GET['id']))
 {
 	$number = docnumber($invoice['number'], $invoice['template'], $invoice['cdate']);
-	if($invoice['doctype']==DOC_INVOICE)
+	if( !$invoice['invoice'])
 		$layout['pagetitle'] = trans('Invoice No. $0', $number);
 	else
 		$layout['pagetitle'] = trans('Credit Note No. $0', $number);
