@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoice_pdf.php,v 1.44 2005/09/13 11:42:41 alec Exp $
+ *  $Id: invoice_pdf.php,v 1.47.2.7 2006/05/03 19:39:01 alec Exp $
  */
 // Faktury w PDF, do uycia z formularzami FT-0100 (c) Polarnet
 // w razie pyta mailto:lexx@polarnet.org
@@ -134,7 +134,7 @@ function invoice_buyer($x,$y)
     global $invoice,$pdf;
     $font_size=10;
     $y=$y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Purchaser:')).'</b>');
-    $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",$invoice['name']));
+    $y=text_wrap($x,$y,350,$font_size,iconv("UTF-8","ISO-8859-2",$invoice['name']),'left');
     $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",$invoice['address']));
     $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",$invoice['zip']." ".$invoice['city']));
     if ($invoice['ten']) 
@@ -178,6 +178,12 @@ function invoice_title($x,$y)
     
     $font_size = 16;
     $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",$type));
+
+    if($type==trans('DUPLICATE'))
+    {
+	    $font_size = 12;
+	    $y=$y-text_align_left($x,$y+4,$font_size,iconv("UTF-8","ISO-8859-2",trans('Duplicate draw-up date:').' '.date('Y/m/d')));
+    }
     
     if($invoice['invoice'])
     	$y += 10;
@@ -188,11 +194,14 @@ function invoice_address_box($x,$y)
 {
     global $invoice,$pdf;
     $font_size=12;
+/*
     $invoice_name = $invoice['name'];
     if (strlen($invoice_name)>25) 
         $invoice_name = preg_replace('/(.{25})/',"$1<i>&gt;</i>\n",$invoice_name);
     $tmp = explode("\n",iconv("UTF-8","ISO-8859-2",$invoice_name));
     foreach ($tmp as $line) $y=$y-text_align_left($x,$y,$font_size,"<b>".$line."</b>");
+*/
+    $y = text_wrap($x, $y, 160, $font_size, iconv("UTF-8","ISO-8859-2",$invoice['name']), 'left');
     if ($invoice['serviceaddr']) {
 	$tmp = explode("\n",iconv("UTF-8","ISO-8859-2",$invoice['serviceaddr']));
 	foreach ($tmp as $line) $y=$y-text_align_left($x,$y,$font_size,"<b>".$line."</b>");
@@ -473,7 +482,7 @@ function invoice_body()
 	default:
 	    require($template);
     }
-    if (!($invoice['last'])) $id=$pdf->newPage(1,$id,'after');
+    if (!$invoice['last']) $id=$pdf->newPage(1,$id,'after');
 }
 
 // brzydki hack dla ezpdf 
@@ -506,8 +515,8 @@ if($_GET['print'] == 'cached')
 	$SESSION->remove('ilm');
 
 	if(sizeof($_POST['marks']))
-		foreach($_POST['marks'] as $id => $mark)
-			$ilm[$id] = $mark;
+		foreach($_POST['marks'] as $idx => $mark)
+			$ilm[$idx] = $mark;
 
 	if(sizeof($ilm))
 		foreach($ilm as $mark)
@@ -522,55 +531,65 @@ if($_GET['print'] == 'cached')
 	if($_GET['cash'])
 	{
 		foreach($ids as $cashid)
-			if($invoiceid = $DB->GetOne('SELECT docid FROM cash, documents WHERE docid = documents.id AND documents.type = 1 AND cash.id = ?', array($cashid)))
+			if($invoiceid = $DB->GetOne('SELECT docid FROM cash, documents WHERE docid = documents.id AND (documents.type = ? OR documents.type = ?) AND cash.id = ?', array(DOC_INVOICE, DOC_CNOTE, $cashid)))
 				$idsx[] = $invoiceid;
 		
 		$ids = array_unique((array)$idsx);
 	}
 
 	sort($ids);
-	$which = ($_GET['which'] != '' ? $_GET['which'] : trans('ORIGINAL+COPY'));
-	$count = (strstr($which,'+') ? sizeof($ids)*2 : sizeof($ids));
+
+	if($_GET['original']) $which[] = trans('ORIGINAL');
+        if($_GET['copy']) $which[] = trans('COPY');
+        if($_GET['duplicate']) $which[] = trans('DUPLICATE');
+
+	if(!sizeof($which)) $which[] = trans('ORIGINAL');
+
+	$count = sizeof($ids) * sizeof($which);
 	$i=0;
 
 	foreach($ids as $idx => $invoiceid)
 	{
 		$invoice = $LMS->GetInvoiceContent($invoiceid);
 		$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
-		foreach(split('\+', $which) as $type)
+		foreach($which as $type)
 		{
 			$i++;
-			if($i == $count) $invoice['last'] = 1;
+			if($i == $count) $invoice['last'] = TRUE;
 			invoice_body();
 		}
 	}
 }
 elseif($_GET['fetchallinvoices'])
 {
-	$which = ($_GET['which'] != '' ? $_GET['which'] : trans('ORIGINAL+COPY'));
-	
 	$ids = $DB->GetCol('SELECT id FROM documents
-				WHERE cdate > ? AND cdate < ? AND type = 1'
+				WHERE cdate >= ? AND cdate <= ? AND (type = ? OR type = ?)'
 				.($_GET['customerid'] ? ' AND customerid = '.$_GET['customerid'] : '')
 				.' ORDER BY cdate',
-				array($_GET['from'], $_GET['to']));
+				array($_GET['from'], $_GET['to'], DOC_INVOICE, DOC_CNOTE));
 	if(!$ids)
 	{
 		$SESSION->close();
 		die;
 	}
 
-	$count = (strstr($which,'+') ? sizeof($ids)*2 : sizeof($ids));
+	if($_GET['original']) $which[] = trans('ORIGINAL');
+        if($_GET['copy']) $which[] = trans('COPY');
+        if($_GET['duplicate']) $which[] = trans('DUPLICATE');
+	
+	if(!sizeof($which)) $which[] = trans('ORIGINAL');
+	
+	$count = sizeof($ids) * sizeof($which);
 	$i=0;
 
 	foreach($ids as $idx => $invoiceid)
 	{
 		$invoice = $LMS->GetInvoiceContent($invoiceid);
 		$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
-		foreach(split('\+', $which) as $type)
+		foreach($which as $type)
 		{
 			$i++;
-			if($i == $count) $invoice['last'] = 1;
+			if($i == $count) $invoice['last'] = TRUE;
 			invoice_body();
 		}
 	}
@@ -582,7 +601,6 @@ elseif($_GET['fetchsingle'])
 	$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
 	$type = trans('ORIGINAL');
 	invoice_body();
-
 }
 elseif($invoice = $LMS->GetInvoiceContent($_GET['id']))
 {
