@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicelist.php,v 1.30 2005/09/13 12:28:19 alec Exp $
+ *  $Id: invoicelist.php,v 1.31.2.3 2006/01/20 20:09:05 alec Exp $
  */
 
 function GetInvoicesList($search=NULL, $cat=NULL, $group=NULL, $order)
@@ -55,13 +55,10 @@ function GetInvoicesList($search=NULL, $cat=NULL, $group=NULL, $order)
 		break;
 	}
 	
-	if($search && $cat)
+	if($search!='' && $cat)
         {
 	        switch($cat)
 		{
-			case 'value':
-			        $where = ' AND value*count = '.intval($search);
-			break;
 			case 'number':
 				$where = ' AND number = '.intval($search);
 			break;
@@ -104,25 +101,34 @@ function GetInvoicesList($search=NULL, $cat=NULL, $group=NULL, $order)
 			name, address, zip, city, template, closed, type, reference '
 	    		.$sqlord.' '.$direction))
 	{
+                if($search!='' && $cat=='value')
+		{
+		        $val = f_round($search);
+			
+			foreach($result as $idx => $row)
+			        if($row['value']==$val)
+			                $result1[] = $result[$idx];
+
+                        $result = $result1;
+	                unset($result1);
+		}
+																																	
 		if($group['group'])
+		{
 			$customers = $DB->GetAllByKey('SELECT customerid AS id
 		        	FROM customerassignments WHERE customergroupid=?', 
 				'id', array($group['group']));
 		
-		foreach($result as $idx => $row)
-		{
-		        $result[$idx]['year'] = date('Y',$row['cdate']);
-			$result[$idx]['month'] = date('m',$row['cdate']);
-			
-			if($group['group'])
+			foreach($result as $idx => $row)
+			{
 				if(!$group['exclude'] && $customers[$result[$idx]['customerid']])
 					$result1[] = $result[$idx];
 				elseif($group['exclude'] && !$customers[$result[$idx]['customerid']])
 					$result1[] = $result[$idx];
-		}
-		
-		if($group['group'])
+			}
+
 			$result = $result1;
+		}
 	}
 	
 	$result['order'] = $order;
