@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicereport.php,v 1.26 2005/09/16 19:52:14 alec Exp $
+ *  $Id: invoicereport.php,v 1.26.2.3 2006/08/18 09:52:06 alec Exp $
  */
 
 $from = $_POST['from'];
@@ -56,7 +56,7 @@ $items = $DB->GetAll('SELECT docid, itemid, taxid, value, count
 	    FROM documents 
 	    LEFT JOIN invoicecontents ON docid = documents.id 
 	    WHERE (type = ? OR type = ?) AND (cdate BETWEEN ? AND ?) 
-	    ORDER BY cdate, docid', array(DOC_INVOICE, DOC_CNOTE, $unixfrom, $unixto));
+	    ORDER BY CEIL(cdate/86400), docid', array(DOC_INVOICE, DOC_CNOTE, $unixfrom, $unixto));
 
 // get documents data
 $docs = $DB->GetAllByKey('SELECT documents.id AS id, number, cdate, customerid, name, address, zip, city, ten, ssn, template, reference
