@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: mailing.php,v 1.48 2005/10/20 17:41:56 alec Exp $
+ *  $Id: mailing.php,v 1.48.2.4 2006/03/28 06:35:22 alec Exp $
  */
 
 function GetEmails($group, $network=NULL, $customergroup=NULL)
@@ -126,7 +126,8 @@ if(isset($_POST['mailing']))
 	if(!$error)
 	{
 		$layout['nomenu'] = TRUE;
-		$mailing['body'] = textwrap($mailing['body']);
+		//$mailing['body'] = textwrap($mailing['body']);
+		$mailing['body'] = wordwrap($mailing['body'], 76, "\n");
 		$mailing['body'] = str_replace("\r", '', $mailing['body']);
 		$SMARTY->assign('mailing', $mailing);
 		$SMARTY->display('header.html');
@@ -149,7 +150,7 @@ if(isset($_POST['mailing']))
 			if(isset($LMS->CONFIG['phpui']['debug_email']))
 				echo '<B>'.trans('Warning! Debug mode (using address $0).',$LMS->CONFIG['phpui']['debug_email']).'</B><BR>';
 			
-			$headers['Date'] = date('D, d F Y H:i:s T');
+			$headers['Date'] = date('r');
 			$headers['From'] = '"'.$mailing['from'].'" <'.$mailing['sender'].'>';
 			$headers['Subject'] = $mailing['subject'];
 			$headers['Reply-To'] = $headers['From'];
