@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netedit.php,v 1.45 2005/05/19 11:01:14 kondi Exp $
+ *  $Id: netedit.php,v 1.46.2.5 2006/07/25 18:40:57 alec Exp $
  */
 
 if(!$LMS->NetworkExists($_GET['id']))
@@ -67,16 +67,29 @@ if(isset($_POST['networkdata']))
 					$error['address'] = trans('New network is too small!');
 				else
 				{
-					if($network['addresslong'] != $networkdata['addresslong'])
-						$networkdata['needshft'] = TRUE;
-
-					if($network['prefix'] < $networkdata['prefix'])
+					$node = $DB->GetRow('SELECT MAX(ipaddr) AS last, MIN(ipaddr) AS first
+							    FROM nodes WHERE (ipaddr>? AND ipaddr<?)',
+							    array($network['addresslong'],ip_long($network['broadcast'])));
+							    
+					$node_pub = $DB->GetRow('SELECT MAX(ipaddr_pub) AS last, MIN(ipaddr_pub) AS first
+							    FROM nodes WHERE (ipaddr_pub>? AND ipaddr_pub<?)',
+							    array($network['addresslong'],ip_long($network['broadcast'])));
+				
+					if($node_pub['first'])
+						$node['first'] = min($node['first'], $node_pub['first']);
+					if($node_pub['last'])
+						$node['last'] = min($node['last'], $node_pub['last']);
+					
+					if(($node['first'] && $node['first'] < $networkdata['addresslong']) ||
+					    ($node['last'] && $node['last'] >= ip_long(getbraddr($networkdata['address'],prefix2mask($networkdata['prefix'])))) )
 					{
-						foreach($network['nodes']['address'] as $key => $value)
-							if($network['nodes']['id'][$key])
-								$lastval = $value;
-						if(ip_long($lastval) >= ip_long(getbraddr($network['address'],prefix2mask($networkdata['prefix']))))
-							$networkdata['needcmp'] = TRUE;
+						$shift = $networkdata['addresslong'] - $network['addresslong'];
+						if($node['first'] + $shift < $networkdata['addresslong'] ||
+						    $node['last'] + $shift >= ip_long(getbraddr($networkdata['address'],prefix2mask($networkdata['prefix'])))
+						)
+							$error['address'] = trans('New network is too small. Put in order IP addresses first!');
+						else
+							$networkdata['needshft'] = TRUE;
 					}
 				}
 			}
@@ -127,17 +140,16 @@ if(isset($_POST['networkdata']))
 	if(!isset($error['dhcpstart']) && !isset($error['dhcpend']))
 	{
 		if(($networkdata['dhcpstart']!='' && $networkdata['dhcpend']=='')||($networkdata['dhcpstart']=='' && $networkdata['dhcpend']!=''))
-			$error['dhcp'] = trans('Both IP addresses for DHCP range are required!');
+			$error['dhcpend'] = trans('Both IP addresses for DHCP range are required!');
 		if($networkdata['dhcpstart']!="" && $networkdata['dhcpend']!="" && !(ip_long($networkdata['dhcpend']) > ip_long($networkdata['dhcpstart'])))
-			$error['dhcp'] = trans('End of DHCP range has to be greater than start!');
+			$error['dhcpend'] = trans('End of DHCP range has to be greater than start!');
 	}
 	
 	if(!$error)
 	{
-		if(isset($networkdata['needcmp']) && $networkdata['needcmp'])
-			$LMS->NetworkCompress($networkdata['id']);
-		if(isset($networkdata['needshft']) && $networkdata['needshft'])
-			$LMS->NetworkShift($network['address'],$network['mask'],($networkdata['addresslong'] - $network['addresslong']));
+	        if(isset($networkdata['needshft']) && $networkdata['needshft'])
+		        $LMS->NetworkShift($network['address'],$network['mask'],$networkdata['addresslong'] - $network['addresslong']);
+
 		$LMS->NetworkUpdate($networkdata);
 		$SESSION->redirect('?m=netinfo&id='.$networkdata['id']);
 	}	
