@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,13 +21,35 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeadd.php,v 1.65 2005/10/07 19:09:11 alec Exp $
+ *  $Id: nodeadd.php,v 1.65.2.4 2006/07/13 07:32:17 alec Exp $
  */
 
-$nodedata = $_POST['nodedata'];
-
-if(isset($nodedata))
+if(isset($_GET['ownerid']))
 {
+	if($LMS->CustomerExists($_GET['ownerid']) == true)
+	{
+		$nodedata['ownerid'] = $_GET['ownerid'];
+		$customerinfo = $LMS->GetCustomer($_GET['ownerid']);
+	}
+	else
+		$SESSION->redirect('?m=customerinfo&id='.$_GET['ownerid']);
+}
+
+$nodedata['access'] = 1;
+
+if(isset($_GET['preip']))
+	$nodedata['ipaddr'] = $_GET['preip'];
+
+if(isset($_GET['premac']))
+	$nodedata['mac'] = $_GET['premac'];
+
+if(isset($_GET['prename']))
+	$nodedata['name'] = $_GET['prename'];
+
+if(isset($_POST['nodedata']))
+{
+	$nodedata = $_POST['nodedata'];
+
 	$nodedata['ipaddr'] = $_POST['nodedataipaddr'];
 	$nodedata['ipaddr_pub'] = $_POST['nodedataipaddr_pub'];
 	$nodedata['mac'] = $_POST['nodedatamac'];
@@ -110,7 +132,11 @@ if(isset($nodedata))
 		{
 			$SESSION->redirect('?m=nodeinfo&id='.$nodeid);
 		}
-		unset($nodedata);
+		
+		$ownerid = $nodedata['ownerid'];
+                unset($nodedata);
+				
+		$nodedata['ownerid'] = $ownerid;
 		$nodedata['reuse'] = '1';
 	}
 	
@@ -118,29 +144,6 @@ if(isset($nodedata))
 		$nodedata['ipaddr_pub'] = '';
 }
 
-if($LMS->CustomerExists($_GET['ownerid']) < 0)
-{
-	$SESSION->redirect('?m=customerinfo&id='.$_GET['ownerid']);
-}
-
-$nodedata['access'] = 1;
-
-if($_GET['ownerid'] && $LMS->CustomerExists($_GET['ownerid']) > 0)
-{
-	$nodedata['ownerid'] = $_GET['ownerid'];
-	$customerinfo = $LMS->GetCustomer($_GET['ownerid']);
-}
-
-if(isset($_GET['preip']) && $nodedata['ipaddr']=='')
-	$nodedata['ipaddr'] = $_GET['preip'];
-
-if(isset($_GET['premac']) && $nodedata['mac']=='')
-	$nodedata['mac'] = $_GET['premac'];
-
-if(isset($_GET['prename']) && $nodedata['name']=='')
-	$nodedata['name'] = $_GET['prename'];
-		
-
 $layout['pagetitle'] = trans('New Node');
 
 $customers = $LMS->GetCustomerNames();
