@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeedit.php,v 1.82 2005/10/07 19:09:11 alec Exp $
+ *  $Id: nodeedit.php,v 1.82.2.4 2006/07/13 07:32:17 alec Exp $
  */
 
 if(!$LMS->NodeExists($_GET['id']))
@@ -115,11 +115,11 @@ if(isset($_POST['nodeedit']))
 
 	if(check_mac($nodeedit['mac']))
 	{
-		if(isset($LMS->CONFIG['phpui']['allow_mac_sharing']) && 
-			$LMS->CONFIG['phpui']['allow_mac_sharing'] == FALSE
-			)
-			if($LMS->GetNodeIDByMAC($nodeedit['mac']) && $LMS->GetNodeMACByID($nodeedit['id'])!=$nodeedit['mac'])
+		if(!chkconfig($CONFIG['phpui']['allow_mac_sharing']))
+		{
+			if($nodeinfo['mac'] != $nodeedit['mac'] && $LMS->GetNodeIDByMAC($nodeedit['mac']))
 				$error['mac'] = trans('Specified MAC address is in use!');
+		}
 	}
 	else
 		$error['mac'] = trans('Incorrect MAC address!');
