@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,9 +21,24 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeinfo.php,v 1.50 2005/10/07 19:09:11 alec Exp $
+ *  $Id: nodeinfo.php,v 1.53.2.3 2006/03/08 19:35:38 alec Exp $
  */
 
+function NodeStats($id, $dt)
+{
+	global $DB;
+	if($stats = $DB->GetRow('SELECT SUM(download) AS download, SUM(upload) AS upload 
+			    FROM stats WHERE nodeid=? AND dt>?', 
+			    array($id, time()-$dt)))
+	{
+		list($result['download']['data'], $result['download']['units']) = setunits($stats['download']);
+		list($result['upload']['data'], $result['upload']['units']) = setunits($stats['upload']);
+		$result['downavg'] = $stats['download']*8/1024/$dt;
+		$result['upavg'] = $stats['upload']*8/1024/$dt;
+	}
+	return $result;
+}
+
 if(!eregi('^[0-9]+$',$_GET['id']))
 {
 	$SESSION->redirect('?m=nodelist');
@@ -62,6 +77,10 @@ $customergroups = $LMS->CustomergroupGetForCustomer($ownerid);
 $othercustomergroups = $LMS->GetGroupNamesWithoutCustomer($ownerid);
 $taxeslist = $LMS->GetTaxes();
 
+$nodestats['hour'] = NodeStats($nodeid, 60*60);
+$nodestats['day'] = NodeStats($nodeid, 60*60*24);
+$nodestats['month'] = NodeStats($nodeid, 60*60*24*30);
+
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 if(!isset($_GET['ownerid']))
@@ -78,6 +97,7 @@ $SMARTY->assign('netdevices',$netdevices);
 $SMARTY->assign('balancelist',$balancelist);
 $SMARTY->assign('customerinfo',$customerinfo);
 $SMARTY->assign('nodeinfo',$nodeinfo);
+$SMARTY->assign('nodestats',$nodestats);
 $SMARTY->assign('assignments',$assignments);
 $SMARTY->assign('customergroups',$customergroups);
 $SMARTY->assign('othercustomergroups',$othercustomergroups);
