@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,70 +21,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: print.php,v 1.86 2005/10/19 10:57:20 alec Exp $
+ *  $Id: print.php,v 1.89.2.10 2006/01/25 14:26:37 alec Exp $
  */
 
 $type = isset($_GET['type']) ? $_GET['type'] : '';
 
 switch($type)
 {
-	case 'customerlist':
-
-		$date = 0;
-		
-		if($_POST['day'])
-		{
-			list($year, $month, $day) = split('/',$_POST['day']);
-			$date = mktime(0,0,0,$month,$day+1,$year);
-		}
-		
-		switch($_POST['filter'])
-		{
-			case 0:
-				$layout['pagetitle'] = trans('Customers List $0$1',($_POST['network'] ? trans(' (Net: $0)',$LMS->GetNetworkName($_POST['network'])) : ''),($_POST['customergroup'] ? trans('(Group: $0)',$LMS->CustomergroupGetName($_POST['customergroup'])) : ''));
-				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['customergroup'], NULL, $date));
-			break;
-			case 1:
-				$layout['pagetitle'] = trans('Interested Customers List');
-				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], NULL, NULL, NULL, $date));
-			break;
-			case 2:
-				$layout['pagetitle'] = trans('List of awaiting customers');
-				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], NULL, NULL, NULL, $date));
-			break;
-			case 3:
-				$layout['pagetitle'] = trans('List of Connected Customers $0$1',($_POST['network'] ? trans(' (Net: $0)',$LMS->GetNetworkName($_POST['network'])) : ''),($_POST['customergroup'] ? trans('(Group: $0)',$LMS->CustomergroupGetName($_POST['customergroup'])) : '')); 
-				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['customergroup'], NULL, $date));
-			break;
-			case 5:
-				$layout['pagetitle'] = trans('List of Disconnected Customers $0$1',($_POST['network'] ? trans(' (Net: $0)',$LMS->GetNetworkName($_POST['network'])) : ''),($_POST['customergroup'] ? trans('(Group: $0)',$LMS->CustomergroupGetName($_POST['customergroup'])) : ''));
-				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['customergroup'], NULL, $date));
-			break;
-			case 6:
-				$layout['pagetitle'] = trans('Indebted Customers List $0$1',($_POST['network'] ? trans(' (Net: $0)',$LMS->GetNetworkName($_POST['network'])) : ''),($_POST['customergroup'] ? trans('(Group: $0)',$LMS->CustomergroupGetName($_POST['customergroup'])) : ''));
-				$SMARTY->assign('customerlist', $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], $_POST['filter'], $_POST['network'], $_POST['customergroup'], NULL, $date));
-			break;
-			case -1:
-				$layout['pagetitle'] = trans('Customers Without Nodes List $0$1',($_POST['network'] ? trans(' (Net: $0)',$LMS->GetNetworkName($_POST['network'])) : ''),($_POST['customergroup'] ? trans('(Group: $0)',$LMS->CustomergroupGetName($_POST['customergroup'])) : ''));
-				if($customerlist = $LMS->GetCustomerList($_POST['order'].','.$_POST['direction'], NULL, NULL, $_POST['customergroup'], NULL, $date))
-				{
-				unset($customerlist['total']);
-				unset($customerlist['state']);
-				unset($customerlist['order']);
-				unset($customerlist['below']);
-				unset($customerlist['over']);
-				unset($customerlist['direction']);
-
-				foreach($customerlist as $idx => $row)
-					if(! $row['account'])
-						$ncustomerlist[] = $customerlist[$idx];
-				}
-				$SMARTY->assign('customerlist', $ncustomerlist);
-			break;	
-		}		
-		$SMARTY->display('printcustomerlist.html');
-	break;
-
 	case 'customerbalance': /********************************************/
 	
 		$from = $_POST['from'];
@@ -149,85 +92,6 @@ switch($type)
 		$SMARTY->display('printcustomerbalance.html');
 	break;	
 	
-	case 'nodelist': /***********************************************/
-		switch($_POST['filter'])
-		{
-			case 0:
-				$layout['pagetitle'] = trans('Nodes List');
-				$nodelist = $LMS->GetNodeList($_POST['order'].','.$_POST['direction'], NULL, NULL, $_POST['network']);
-			break;
-			case 1:
-				$layout['pagetitle'] = trans('List of Disconnected Nodes');
-				$nodelist = $LMS->GetNodeList($_POST['order'].','.$_POST['direction'], NULL, NULL, $_POST['network'], 1);
-			break;
-			case 2:
-				$layout['pagetitle'] = trans('List of Connected Nodes');
-				$nodelist = $LMS->GetNodeList($_POST['order'].','.$_POST['direction'], NULL, NULL,  $_POST['network'], 2);
-			break;
-			case 3:
-				$layout['pagetitle'] = trans('Nodes List for Customers In Debt');
-
-				$order=$_POST['order'].','.$_POST['direction'];
-				if($order=='')
-					$order='name,asc';
-
-				list($order,$direction) = explode(',',$order);
-
-				($direction=='desc') ? $direction = 'desc' : $direction = 'asc';
-
-				switch($order)
-				{
-					case 'name':
-						$sqlord = ' ORDER BY nodes.name';
-					break;
-					case 'id':
-						$sqlord = ' ORDER BY id';
-					break;
-					case 'mac':
-						$sqlord = ' ORDER BY mac';
-					break;
-				    	case 'ip':
-						$sqlord = ' ORDER BY ipaddr';
-					break;
-					case 'ownerid':
-						$sqlord = ' ORDER BY ownerid';
-					break;
-				    	case 'owner':
-						$sqlord = ' ORDER BY owner';
-					break;
-				}
-
-				if($_POST['network'])
-					$net = $LMS->GetNetworkParams($_POST['network']);
-
-				$nodelist = $DB->GetAll('SELECT nodes.id AS id, inet_ntoa(ipaddr) AS ip, mac, 
-					    nodes.name AS name, nodes.info AS info, 
-					    COALESCE(SUM(value), 0.00)/(CASE COUNT(DISTINCT nodes.id) WHEN 0 THEN 1 ELSE COUNT(DISTINCT nodes.id) END) AS balance, '
-					    .$DB->Concat('UPPER(lastname)',"' '",'customers.name').' AS owner
-					    FROM nodes LEFT JOIN customers ON (ownerid = customers.id)
-					    LEFT JOIN cash ON (cash.customerid = customers.id)'
-					    .($net ? ' WHERE ((ipaddr > '.$net['address'].' AND ipaddr < '.$net['broadcast'].') OR (ipaddr_pub > '.$net['address'].' AND ipaddr_pub < '.$net['broadcast'].'))' : '')
-					    .'GROUP BY nodes.id, ipaddr, mac, nodes.name, nodes.info, customers.lastname, customers.name
-					    HAVING SUM(value) < 0'
-					    .($sqlord != '' ? $sqlord.' '.$direction : ''));
-				
-				$SMARTY->assign('nodelist', $nodelist);
-				$SMARTY->display('printindebtnodelist.html');
-				$SESSION->close();
-				die;
-			break;
-		}	
-
-		unset($nodelist['total']);
-		unset($nodelist['order']);
-		unset($nodelist['direction']);
-		unset($nodelist['totalon']);
-		unset($nodelist['totaloff']);
-		
-		$SMARTY->assign('nodelist', $nodelist);
-		$SMARTY->display('printnodelist.html');
-	break;
-
 	case 'balancelist': /********************************************/
 	
 		$from = $_POST['balancefrom'];
@@ -369,11 +233,14 @@ switch($type)
 			$date['from'] = mktime(0,0,0); //pocztek dnia dzisiejszego
 		}
 
-		if($_POST['invoiceorg'] && !$_POST['invoicecopy']) $witch = trans('ORIGINAL');
-		if(!$_POST['invoiceorg'] && $_POST['invoicecopy']) $witch = trans('COPY');
+		$type = '';
+		$type .= $_POST['invoiceorg'] ? '&original=1' : '';
+		$type .= $_POST['invoicecopy'] ? '&copy=1' : '';
+		$type .= $_POST['invoicedup'] ? '&duplicate=1' : '';
+		if(!$type) $type = '&oryginal=1';
 		
 		$layout['pagetitle'] = trans('Invoices');
-		header('Location: ?m=invoice&fetchallinvoices=1&which='.$witch.'&customerid='.$_POST['customer'].'&from='.$date['from'].'&to='.$date['to']);
+		header('Location: ?m=invoice&fetchallinvoices=1'.$type.'&customerid='.$_POST['customer'].'&from='.$date['from'].'&to='.$date['to']);
 	break;	
 
 	case 'transferforms': /********************************************/
@@ -393,21 +260,36 @@ switch($type)
 			$date['to'] = mktime(23,59,59); //koniec dnia dzisiejszego
 		}
 		
-		header('Location: ?m=transferforms&customerid='.$_POST['customer'].'&from='.$date['from'].'&to='.$date['to']);
+		$_GET['from'] = $date['from'];
+		$_GET['to'] = $date['to'];
+		$_GET['customerid'] = $_POST['customer'];
+		
+		require_once($_MODULES_DIR.'/transferforms.php');
+		
 	break;	
 
+	case 'transferforms2': /********************************************/
+		
+		require_once($_MODULES_DIR.'/transferforms2.php');
+	break;
+
 	case 'liabilityreport': /********************************************/
 	
 		if(isset($_POST['day']) && $_POST['day']) 
 		{
 			list($year, $month, $day) = split('/',$_POST['day']);
 			$reportday = mktime(0,0,0,$month,$day,$year);
+			$today = $reportday;
 		} else 
+		{
 			$reportday = time();
-		
+			$today = mktime(0,0,0);
+		}
+
 		$layout['pagetitle'] = trans('Liability Report on $0',date('Y/m/d', $reportday));
 
-		$order = (isset($_POST['order']) ? $_POST['order'] : 'brutto').','.(isset($_POST['direction']) ? $_POST['direction'] : 'asc');
+		$order = $_POST['order'];
+		$direction = $_POST['direction'];
 		$customerid = (isset($_POST['customer']) ? $_POST['customer'] : 0);
 
 		$yearday = date('z', $reportday);
@@ -428,37 +310,76 @@ switch($type)
 		    default: $quarterday = $monthday + 200; break;
 		}
 		
-		list($order,$direction)=explode(',', $order);
-
-		($direction != 'desc') ? $direction = 'ASC' : $direction = 'DESC';
-
-		switch($order)
-		{
-			case 'customername':
-				$sqlord = 'ORDER BY customername';
-			break;
-			default:
-				$sqlord = 'ORDER BY brutto';
-			break;
-		}
+		$suspension_percentage = $CONFIG['finances']['suspension_percentage'];
 		
 		if($taxes = $LMS->GetTaxes($reportday, $reportday))
+		{
 			foreach($taxes as $tax)
 			{
-				$list =  $DB->GetAllByKey('SELECT customerid AS id, '.$DB->Concat('UPPER(lastname)',"' '",'customers.name').' AS customername, '
-					.$DB->Concat('city',"' '",'address').' AS address, ten, SUM(tariffs.value) AS value  
+				$list1 =  $DB->GetAllByKey('SELECT customerid AS id, '.$DB->Concat('UPPER(lastname)',"' '",'customers.name').' AS customername, '
+					.$DB->Concat('city',"' '",'address').' AS address, ten, 
+					SUM(CASE suspended 
+					    WHEN 0 THEN 
+						(CASE discount 
+						    WHEN 0 THEN tariffs.value 
+						    ELSE ((100 - discount) * tariffs.value) / 100 
+						END) 
+					    ELSE 
+						(CASE discount 
+						    WHEN 0 THEN tariffs.value * '.$suspension_percentage.' / 100 
+						    ELSE tariffs.value * discount * '.$suspension_percentage.' / 10000 
+						END) 
+					    END) AS value
+						
 					FROM assignments, tariffs, customers
-					WHERE customerid = customers.id AND tariffid = tariffs.id AND taxid=?
-					AND deleted=0 AND (datefrom<=?) AND ((dateto>=?) OR dateto=0) 
-					AND ((period=0 AND at=?) OR (period=1 AND at=?) OR (period=2 AND at=?) OR (period=3 AND at=?)) '
+					WHERE customerid = customers.id 
+					AND tariffid = tariffs.id AND taxid=?
+					AND deleted=0 
+					AND (datefrom<=? OR datefrom=0) AND (dateto>=? OR dateto=0) 
+					AND ((period='.DISPOSABLE.' AND at=?)
+					    OR (period='.WEEKLY.'. AND at=?) 
+					    OR (period='.MONTHLY.' AND at=?) 
+					    OR (period='.QUARTERLY.' AND at=?) 
+					    OR (period='.YEARLY.' AND at=?)) '
 					.($customerid ? 'AND customerid='.$customerid : ''). 
-					' GROUP BY customerid, lastname, customers.name, city, address, ten '
-					.($sqlord != '' ? $sqlord.' '.$direction : ''), 'id',
-					array($tax['id'],$reportday, $reportday, $weekday, $monthday, $quarterday, $yearday));
+					' GROUP BY customerid, lastname, customers.name, city, address, ten ', 'id',
+					array($tax['id'], $reportday, $reportday, $today, $weekday, $monthday, $quarterday, $yearday));
+
+				$list2 =  $DB->GetAllByKey('SELECT customerid AS id, '.$DB->Concat('UPPER(lastname)',"' '",'customers.name').' AS customername, '
+					.$DB->Concat('city',"' '",'address').' AS address, ten, 
+					SUM(CASE suspended 
+					    WHEN 0 THEN 
+						(CASE discount 
+						    WHEN 0 THEN liabilities.value 
+						    ELSE ((100 - discount) * liabilities.value) / 100 
+						END) 
+					    ELSE 
+						(CASE discount 
+						    WHEN 0 THEN liabilities.value * '.$suspension_percentage.' / 100 
+						    ELSE liabilities.value * discount * '.$suspension_percentage.' / 10000 
+						END) 
+					    END) AS value
+					FROM assignments, liabilities, customers
+					WHERE customerid = customers.id 
+					AND liabilityid = liabilities.id AND taxid=?
+					AND deleted=0 
+					AND (datefrom<=? OR datefrom=0) AND (dateto>=? OR dateto=0) 
+					AND ((period='.DISPOSABLE.' AND at=?)
+					    OR (period='.WEEKLY.'. AND at=?) 
+					    OR (period='.MONTHLY.' AND at=?) 
+					    OR (period='.QUARTERLY.' AND at=?) 
+					    OR (period='.YEARLY.' AND at=?)) '
+					.($customerid ? 'AND customerid='.$customerid : ''). 
+					' GROUP BY customerid, lastname, customers.name, city, address, ten ', 'id',
+					array($tax['id'], $reportday, $reportday, $today, $weekday, $monthday, $quarterday, $yearday));
+				
+				$list = array_merge((array) $list1, (array) $list2);
+
 				if($list)
 				{
-					foreach($list as $idx => $row)
+					foreach($list as $row)
 					{
+						$idx = $row['id'];
 						if(!isset($reportlist[$idx]))
 						{ 
 							$reportlist[$idx]['id'] = $row['id'];
@@ -467,15 +388,50 @@ switch($type)
 							$reportlist[$idx]['ten'] = $row['ten'];
 						}
 						$reportlist[$idx]['value'] += $row['value'];
-						$reportlist[$idx][$tax['id']]['netto'] = round($row['value']-$row['value']*$tax['value']/100, 2);
+						$reportlist[$idx][$tax['id']]['netto'] = round($row['value']/($tax['value']+100)*100, 2);
 						$reportlist[$idx][$tax['id']]['tax'] = $row['value'] - $reportlist[$idx][$tax['id']]['netto'];
 						$reportlist[$idx]['taxsum'] += $reportlist[$idx][$tax['id']]['tax'];
 						$total['netto'][$tax['id']] += $reportlist[$idx][$tax['id']]['netto'];
 						$total['tax'][$tax['id']] += $reportlist[$idx][$tax['id']]['tax'];
 					}
+					
+					switch($order)
+					{
+						case 'customername':
+							foreach($reportlist as $idx => $row)
+							{
+	        						$table['idx'][] = $idx;
+			        				$table['customername'][] = $row['customername'];
+							}
+	    						if(is_array($table))
+	    						{
+			            				array_multisort($table['customername'],($direction == 'desc' ? SORT_DESC : SORT_ASC), $table['idx']);
+					        		foreach($table['idx'] as $idx)
+					        			$tmplist[] = $reportlist[$idx];
+							}
+							$reportlist = $tmplist;		
+						break;
+						default:
+							foreach($reportlist as $idx => $row)
+							{
+	        						$table['idx'][] = $idx;
+    								$table['value'][] = $row['value'];
+							}
+		    					if(is_array($table))
+			    				{
+	    		        				array_multisort($table['value'],($direction == 'desc' ? SORT_DESC : SORT_ASC), $table['idx']);
+					    	    		foreach($table['idx'] as $idx)
+									$tmplist[] = $reportlist[$idx];
+							}
+							$reportlist = $tmplist;				
+						break;
+					}
+
 				}
 			}
 
+		}
+
 		$SMARTY->assign('reportlist', $reportlist);
 		$SMARTY->assign('total',$total);
 		$SMARTY->assign('taxes', $taxes);
@@ -483,77 +439,15 @@ switch($type)
 		$SMARTY->display('printliabilityreport.html');
 	break;
 
-	case 'customertraffic': /******************************************/
-
-		$layout['pagetitle'] = trans('Stats of Customer $0 in month $1', $LMS->GetCustomerName($_POST['customer']), strftime('%B %Y', mktime(0,0,0,$_POST['month'],1,$_POST['year'])));
-	
-		$from = mktime(0,0,0,$_POST['month'],1,$_POST['year']);
-		$to = mktime(0,0,0,$_POST['month']+1,1,$_POST['year']);
-
-    		if($list = $DB->GetAll('SELECT download, upload, dt
-	                	    FROM stats
-				    LEFT JOIN nodes ON (nodeid = nodes.id)
-				    WHERE ownerid = ? AND dt >= ? AND dt < ?',
-				    array($_POST['customer'], $from, $to)))
-		{
-			for($i=1; $i<=date('t',$from); $i++)
-				$stats[$i]['date'] = mktime(0,0,0,$_POST['month'],$i,$_POST['year']); 
-				
-			foreach($list as $row)
-			{
-				$day = date('j', $row['dt']);
-				
-				$stats[$day]['download'] += $row['download'];
-				$stats[$day]['upload'] += $row['upload'];
-			}
-			
-			for($i=1; $i<=date('t',$from); $i++)
-			{
-				$stats[$i]['upavg'] = $stats[$i]['upload']/86400;
-				$stats[$i]['downavg'] = $stats[$i]['download']/86400;
-				
-				$listdata['upload'] += $stats[$i]['upload'];
-				$listdata['download'] += $stats[$i]['download'];
-				$listdata['upavg'] += $stats[$i]['upavg'];
-				$listdata['downavg'] += $stats[$i]['downavg'];
-				
-				list($stats[$i]['upload'], $stats[$i]['uploadunit']) = setunits($stats[$i]['upload']);
-				list($stats[$i]['download'], $stats[$i]['downloadunit']) = setunits($stats[$i]['download']);
-				list($stats[$i]['upavg'], $stats[$i]['upavgunit']) = setunits($stats[$i]['upavg']);
-				list($stats[$i]['downavg'], $stats[$i]['downavgunit']) = setunits($stats[$i]['downavg']);
-			}
-			
-			list($listdata['upload'], $listdata['uploadunit']) = setunits($listdata['upload']);
-			list($listdata['download'], $listdata['downloadunit']) = setunits($listdata['download']);
-			list($listdata['upavg'], $listdata['upavgunit']) = setunits($listdata['upavg']);
-			list($listdata['downavg'], $listdata['downavgunit']) = setunits($listdata['downavg']);
-		}
-
-		$SMARTY->assign('stats', $stats);
-		$SMARTY->assign('listdata', $listdata);
-		$SMARTY->display('printcustomertraffic.html');
-	break;
-
 	default: /*******************************************************/
 	
 		$layout['pagetitle'] = trans('Printing');
 		
-		$yearstart = date('Y',$DB->GetOne('SELECT MIN(dt) FROM stats'));
-		$yearend = date('Y',$DB->GetOne('SELECT MAX(dt) FROM stats'));
-		for($i=$yearstart; $i<$yearend+1; $i++)
-			$statyears[] = $i;
-		for($i=1; $i<13; $i++)
-			$months[$i] = strftime('%B', mktime(0,0,0,$i,1));
-		
-		$SMARTY->assign('currmonth', date('n'));
-		$SMARTY->assign('curryear', date('Y'));
-		$SMARTY->assign('statyears', $statyears);
-		$SMARTY->assign('months', $months);
 		$SMARTY->assign('customers', $LMS->GetCustomerNames());
 		$SMARTY->assign('users', $LMS->GetUserNames());
 		$SMARTY->assign('networks', $LMS->GetNetworks());
 		$SMARTY->assign('customergroups', $LMS->CustomergroupGetAll());
-		$SMARTY->assign('printmenu', isset($_GET['menu']) ? $_GET['menu'] : '');
+		$SMARTY->assign('printmenu', 'finances');
 		$SMARTY->display('printindex.html');
 	break;
 }
