@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtmessageadd.php,v 1.42 2005/08/07 07:20:01 alec Exp $
+ *  $Id: rtmessageadd.php,v 1.42.2.3 2006/03/27 19:10:57 alec Exp $
  */
 
 function MessageAdd($msg, $headers, $file=NULL)
@@ -146,7 +146,7 @@ if(isset($_POST['message']))
 				$recipients = $message['destination'];
 				$message['mailfrom'] = $user['email'] ? $user['email'] : $queue['email'];
 
-				$headers['Date'] = date('D, d F Y H:i:s T');
+				$headers['Date'] = date('r');
 				$headers['From'] = $mailfname.' <'.$message['mailfrom'].'>';
 				$headers['To'] = '<'.$message['destination'].'>';
 				$headers['Subject'] = $message['subject'];
@@ -198,7 +198,7 @@ if(isset($_POST['message']))
 			if($message['customerid'])
 				$message['mailfrom'] = $LMS->GetCustomerEmail($message['customerid']);
 
-			$headers['Date'] = date('D, d F Y H:i:s T');
+			$headers['Date'] = date('r');
 			$headers['From'] = $mailfname.' <'.$message['mailfrom'].'>';
 			$headers['To'] = '<'.$message['destination'].'>';
 			$headers['Subject'] = $message['subject'];
