@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffadd.php,v 1.46 2005/06/30 10:05:02 alec Exp $
+ *  $Id: tariffadd.php,v 1.46.2.3 2006/02/19 12:02:57 alec Exp $
  */
 
 $tariffadd = $_POST['tariffadd'];
@@ -31,7 +31,7 @@ if(isset($tariffadd))
 	foreach($tariffadd as $key => $value)
 		$tariffadd[$key] = trim($value);
 
-	if($tariffadd['name']=='' && $tariffadd['comment']=='' && $tariffadd['value']=='')
+	if($tariffadd['name']=='' && $tariffadd['description']=='' && $tariffadd['value']=='')
 	{
 		$SESSION->redirect('Location: ?m=tarifflist');
 	}
