@@ -1,8 +1,8 @@
 <?php
 
-/* LMS version 1.7.4 Wraith
+/* LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -20,7 +20,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: traffic.php,v 1.31 2005/10/05 11:04:56 alec Exp $
+ *  $Id: traffic.php,v 1.32.2.3 2006/01/16 09:35:29 alec Exp $
  */
 
 function Traffic($from = 0, $to = 0, $net = 0, $order = '', $limit = 0)
@@ -33,13 +33,13 @@ function Traffic($from = 0, $to = 0, $net = 0, $order = '', $limit = 0)
 	else
 		$fromdate = $from;
 	if (is_array($to))
-		$todate = mktime($to['Hour'],$to['Minute'],59,$to['Month'],$to['Day'],$to['Year']);
+		$todate = mktime($to['Hour'],$to['Minute'],0,$to['Month'],$to['Day'],$to['Year']);
 	else
 		$todate = $to;
 
 	$delta = ($todate-$fromdate) ? ($todate-$fromdate) : 1;
 
-	$dt = "( dt >= $fromdate AND dt <= $todate )";
+	$dt = "( dt >= $fromdate AND dt < $todate )";
 
 	// nets
 	if ($net != "allnets")
@@ -95,8 +95,8 @@ function Traffic($from = 0, $to = 0, $net = 0, $order = '', $limit = 0)
 		{
 			$traffic['upload']['data'][] = $row['upload'];
 			$traffic['download']['data'][] = $row['download'];
-			$traffic['upload']['avg'][] = $row['upload']/($delta*1024);
-			$traffic['download']['avg'][] = $row['download']/($delta*1024);
+			$traffic['upload']['avg'][] = $row['upload']*8/($delta*1024);
+			$traffic['download']['avg'][] = $row['download']*8/($delta*1024);
 			$traffic['upload']['name'][] = ($row['name'] ? $row['name'] : 'nieznany (ID: '.$row['nodeid'].')');
 			$traffic['download']['name'][] = ($row['name'] ? $row['name'] : 'nieznany (ID: '.$row['nodeid'].')');
 			$traffic['upload']['ipaddr'][] = $row['ip'];
@@ -109,8 +109,8 @@ function Traffic($from = 0, $to = 0, $net = 0, $order = '', $limit = 0)
 
 		$traffic['upload']['sum']['data'] = $uploadsum;
 		$traffic['download']['sum']['data'] = $downloadsum;
-		$traffic['upload']['avgsum'] = $uploadsum/($delta*1024);
-		$traffic['download']['avgsum'] = $downloadsum/($delta*1024);
+		$traffic['upload']['avgsum'] = $uploadsum*8/($delta*1024);
+		$traffic['download']['avgsum'] = $downloadsum*8/($delta*1024);
 
 		// get maximum data from array
 
