@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.7.4 Wraith
+ * LMS version 1.8.12 Tagan
  *
- *  (C) Copyright 2001-2005 LMS Developers
+ *  (C) Copyright 2001-2006 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: welcome.php,v 1.46 2005/05/26 13:24:57 alec Exp $
+ *  $Id: welcome.php,v 1.46.2.3 2007/04/19 08:29:52 alec Exp $
  */
 
 require_once($_LIB_DIR.'/Sysinfo.class.php');
@@ -32,9 +32,18 @@ $SI = new Sysinfo;
 $layout['pagetitle'] = 'LAN Management System';
 
 $layout['dbversion'] = $DB->GetDBVersion();
-$layout['dbtype'] = $LMS->CONFIG['database']['type'];
+$layout['dbtype'] = $CONFIG['database']['type'];
+
+$content = $LMS->CheckUpdates();
+
+if(isset($content['newer_version']))
+{
+	list($v, ) = split(' ', $LMS->_version);
+
+	if(version_compare($content['newer_version'], $v)>0)
+		$SMARTY->assign('newer_version', $content['newer_version']);
+}
 
-$SMARTY->assign('updates', $LMS->CheckUpdates());
 $SMARTY->assign('regdata', $LMS->GetRegisterData());
 $SMARTY->assign('rtstats', $LMS->RTStats());
 $SMARTY->assign('sysinfo',$SI->get_sysinfo());
